<?php

/**
 * Lnk.Bio
 *
 * @package     LnkBio
 * @author      Lnk.Bio
 * @copyright   2022 Gimucco PTE LTD
 * @license     GPL-2.0-or-later
 *
 * @wordpress-plugin
 * Plugin Name: Lnk.Bio
 * Plugin URI:  https://lnk.bio/manage/integrations/wordpress
 * Description: Auto-publish a new Lnk on your Lnk.Bio page everytime you publish a new WordPress blog post.
 * Version:     0.0.3
 * Author:      Lnk.Bio
 * Author URI:  https://lnk.bio
 * Text Domain: lnkbio
 * License:     GPL v2 or later
 * License URI: http://www.gnu.org/licenses/gpl-2.0.txt
 */

function lnkbio_admin() {
	include plugin_dir_path(__FILE__).'admin.php';
}
function lnkbio_load_menu() {
	$menu = add_submenu_page(
		'tools.php',
		'Lnk.Bio integration',
		'Lnk.Bio',
		'manage_options',
		'lnkbio',
		'lnkbio_admin'
	);
	add_action('load-'.$menu, 'lnkbio_load_admin_js');
}

add_filter('https_ssl_verify', '__return_false');
add_action('wp_insert_post', 'lnkbio_api_sync', 10, 3);
add_action('added_post_meta', 'lnkbio_api_syncMeta', 10, 4);
// add_action('updated_post_meta', 'lnkbio_api_syncMeta', 10, 4);


if (is_admin()) { // admin actions
	add_action('admin_menu', 'lnkbio_load_menu');
	add_action('admin_init', 'lnkbio_register_settings');
	add_action('wp_ajax_nopriv_lnkbio_api_test', 'lnkbio_api_test');
	add_action('wp_ajax_lnkbio_api_test', 'lnkbio_api_test');
} else {
	// non-admin enqueues, actions, and filters
}

function lnkbio_register_settings() {
	register_setting('lnkbio_options', 'lnkbio_id');
	register_setting('lnkbio_options', 'lnkbio_secret');
}

function lnkbio_load_admin_js() {
	add_action('admin_enqueue_scripts', 'lnkbio_enqueue_admin_js');
}

function lnkbio_enqueue_admin_js() {
	wp_enqueue_script('lnkbio', plugin_dir_url(__FILE__).'lnkbio.js', array('jquery'), null, true);
}

function lnkbio_api_test() {
	$outcome = lnkbio_api_post('https://lnk.bio/api', ['ACTION' => 'WP_test']);
	if ($outcome->status) {
		echo 1;
	}
	die();
}

function lnkbio_api_post(string $url, array $data) {
	$data['id'] = get_option('lnkbio_id');
	$data['secret'] = get_option('lnkbio_secret');
	$params = array(
		'method' => 'POST',
		'body' => http_build_query($data)
	);
	$curl = new WP_Http_Curl();
	$outcome = $curl->request($url, $params);
	$outcome = $outcome['body'];
	return json_decode($outcome);
}

function lnkbio_api_sync($post_id, $post, $update) {
	if ($post->post_status === 'publish') {
		if (!get_option('lnkbio_id') || !get_option('lnkbio_secret')) {
			return;
		}
		wp_remote_post(
			'https://lnk.bio/api',
			[
				'blocking' => false,
				'body' => [
					'ACTION' 	=> 'WP_sync',
					'post_id' 	=> $post_id,
					'post'    	=> json_encode($post),
					'id'		=> get_option('lnkbio_id'),
					'secret' 	=> get_option('lnkbio_secret'),
					'permalink' => get_permalink($post)
				]
			]
		);
	}
}

function lnkbio_api_syncMeta(int $meta_id, int $object_id, string $meta_key, string $meta_value) {
	if ($meta_key != "_thumbnail_id") {
		return;
	}
	$post = get_post($object_id);
	if ($post->post_status === 'publish') {
		if (!get_option('lnkbio_id') || !get_option('lnkbio_secret')) {
			return;
		}
		wp_remote_post(
			'https://lnk.bio/api',
			[
				'blocking' => false,
				'body' => [
					'ACTION' 	=> 'WP_sync',
					'post_id' 	=> $object_id,
					'post'    	=> json_encode($post),
					'id'		=> get_option('lnkbio_id'),
					'secret' 	=> get_option('lnkbio_secret'),
					'permalink' => get_permalink($post),
					'image' 		=> wp_get_attachment_url($meta_value)
				]
			]
		);
	}
}
